@@ -3,12 +3,10 @@ import sys
 from os import path
 
 from .snowcrypt import decrypt_aaxc, deriveKeyIV
-from .localExceptions import *
-from .parser import arg
+from .localExceptions import NotDecryptable
+from .myparser import arg
 from .tinytag import MP4
 
-fixedKey = bytes.fromhex('77214d4b196a87cd520045fd20a51d67')
-
 
 def signal_handler(sig, frame):
     sys.exit(print('\nsnowcrypt: received SIGINT. exiting'))
@@ -42,12 +40,9 @@ def main():
             "The file you provided doesn't end with '.aax' or '.aaxc'. " +
             "Please supply one that does.")
 
-    key = key if not arg('key') else arg('key'),
-    iv = iv if not arg('iv') else arg('iv'),
-
     decrypt_aaxc(
         infile,
         outfile,
-        key,
-        iv,
+        key if not arg('key') else arg('key'),
+        iv if not arg('iv') else arg('iv'),
     )
